package parkup.controllers;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import parkup.entities.ParkingSpace;
import parkup.services.ParkingSpaceService;

import java.util.List;

@RestController
public class ParkingSpaceController {
    private final ParkingSpaceService parkingSpaceService;

    @Autowired
    public ParkingSpaceController(ParkingSpaceService parkingSpaceService) {
        this.parkingSpaceService = parkingSpaceService;
    }

    @GetMapping({"/parkingSpace"})
    public List<ParkingSpace> getAllParkingSpaces() {
        return parkingSpaceService.getAllParkingSpaces();
    }

    @GetMapping({"/parkingSpace/{parkingSpaceId}"})
    public ParkingSpace getParkingSpace(@PathVariable int parkingSpaceId) {
        ParkingSpace parkingSpace = parkingSpaceService.findById(parkingSpaceId);
        if (parkingSpace != null) {
            return parkingSpace;
        } else {
            throw new RuntimeException("ParkingSpace not found");
        }
    }

    @PostMapping({"/parkingSpace"})
    public void addParkingSpace(@RequestBody ParkingSpace parkingSpace) {
        //System.out.println("???????");
        parkingSpaceService.addParkingSpace(parkingSpace);
    }

    @PutMapping({"/parkingSpace/{parkingSpaceId}"})
    public void updateParkingSpace(@PathVariable int parkingSpaceId, @RequestBody ParkingSpace parkingSpace) {
        parkingSpaceService.updateParkingSpace(parkingSpaceId, parkingSpace.getPsName(), parkingSpace.isTaken(), parkingSpace.isHandicaped());
    }

    @DeleteMapping({"/parkingSpace/{parkingSpaceId}"})
    public void deleteParkingSpace(@PathVariable int parkingSpaceId) {
        parkingSpaceService.deleteParkingSpace(parkingSpaceId);
    }
}
